summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--CONTRIBUTING.md2
-rw-r--r--README.md8
-rw-r--r--composer.json9
-rw-r--r--examples/download.php2
-rw-r--r--examples/extract.php6
-rw-r--r--examples/filtering.php6
-rw-r--r--examples/json.php2
-rw-r--r--examples/merge.php10
-rw-r--r--examples/switchmode.php6
-rw-r--r--examples/table.php2
-rw-r--r--examples/writing.php4
-rw-r--r--examples/xml.php2
-rw-r--r--phpunit.xml2
-rw-r--r--src/AbstractCsv.php12
-rw-r--r--src/ConverterTrait.php14
-rw-r--r--src/Iterator/IteratorFilter.php12
-rw-r--r--src/Iterator/IteratorInterval.php12
-rw-r--r--src/Iterator/IteratorQuery.php12
-rw-r--r--src/Iterator/IteratorSortBy.php12
-rw-r--r--src/Iterator/MapIterator.php12
-rw-r--r--src/Reader.php18
-rw-r--r--src/Writer.php14
-rw-r--r--test/CsvTest.php2
-rw-r--r--test/Iterator/IteratorQueryTest.php4
-rw-r--r--test/ReaderTest.php4
-rw-r--r--test/WriterTest.php2
26 files changed, 97 insertions, 94 deletions
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index b226417..bbf98c0 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -2,7 +2,7 @@
Contributions are **welcome** and will be fully **credited**.
-We accept contributions via Pull Requests on [Github](https://github.com/nyamsprod/Bakame.url).
+We accept contributions via Pull Requests on [Github](https://github.com/theleague/csv).
## Pull Requests
diff --git a/README.md b/README.md
index 99de362..d4f809c 100644
--- a/README.md
+++ b/README.md
@@ -15,7 +15,7 @@ This package is compliant with [PSR-1], [PSR-2], and [PSR-4].
System Requirements
-------
-You need **PHP >= 5.4.0** and the `mbstring` extension to use `Bakame\Csv` but the latest stable version of PHP is recommended.
+You need **PHP >= 5.4.0** and the `mbstring` extension to use `League\Csv` but the latest stable version of PHP is recommended.
Install
-------
@@ -54,8 +54,8 @@ Usage
* If you have your LC_CTYPE set to a locale that's using UTF-8 and you try to parse a file that's not in UTF-8, PHP will cut your fields the moment it encounters a byte it can't understand (i.e. any outside of ASCII that doesn't happen to be part of a UTF-8 character which it likely isn't). [This gist will show you a possible solution](https://gist.github.com/pilif/9137146) to this problem by using [PHP stream filter](http://www.php.net/manual/en/stream.filters.php). This tip is from [Philip Hofstetter](https://github.com/pilif)
* When merging multiples CSV documents don't forget to set the main CSV object
- as a `Bakame\Csv\Writer` object with the `$open_mode = 'a+'` to preserve its content.
- This setting is of course not required when your main `Bakame\Csv\Writer` object is
+ as a `League\Csv\Writer` object with the `$open_mode = 'a+'` to preserve its content.
+ This setting is of course not required when your main `League\Csv\Writer` object is
created from String
* **If you are on a Mac OS X Server**, add the following lines before using the library to help [PHP detect line ending in Mac OS X](http://php.net/manual/en/function.fgetcsv.php#refsect1-function.fgetcsv-returnvalues).
@@ -69,7 +69,7 @@ if (! ini_get("auto_detect_line_endings")) {
Documentation
-------------
-Fractal has [full documentation](http://csv.thephpleague.com), powered by [Sculpin](https://sculpin.io).
+Csv has [full documentation](http://csv.thephpleague.com), powered by [Sculpin](https://sculpin.io).
Contribute to this documentation in the [sculpin branch](https://github.com/thephpleague/csv/tree/sculpin/source).
diff --git a/composer.json b/composer.json
index 8f7eb4c..84a4b6d 100644
--- a/composer.json
+++ b/composer.json
@@ -1,5 +1,5 @@
{
- "name": "bakame/csv",
+ "name": "league/csv",
"type": "library",
"description" : "Csv data manipulation made easy in PHP 5.4+",
"keywords": ["csv", "import", "export", "read", "write", "filter"],
@@ -18,8 +18,11 @@
},
"autoload": {
"psr-4": {
- "Bakame\\Csv\\": "src",
- "Bakame\\CSv\\": "test"
+ "League\\Csv\\": "src",
+ "League\\CSv\\": "test"
}
+ },
+ "replaces": {
+ "bakame/csv": "*"
}
}
diff --git a/examples/download.php b/examples/download.php
index 150827c..1578b51 100644
--- a/examples/download.php
+++ b/examples/download.php
@@ -1,6 +1,6 @@
<?php
-use Bakame\Csv\Reader;
+use League\Csv\Reader;
require '../vendor/autoload.php';
diff --git a/examples/extract.php b/examples/extract.php
index 9e884fa..9fbdb81 100644
--- a/examples/extract.php
+++ b/examples/extract.php
@@ -1,6 +1,6 @@
<?php
-use Bakame\Csv\Reader;
+use League\Csv\Reader;
require '../vendor/autoload.php';
@@ -18,11 +18,11 @@ $res = $inputCsv->setOffset(800)->setLimit(25)->fetchAll();
<html lang="fr">
<head>
<meta charset="<?=$inputCsv->getEncoding()?>">
- <title>\Bakame\Csv\Reader simple usage</title>
+ <title>\League\Csv\Reader simple usage</title>
<link rel="stylesheet" href="example.css">
</head>
<body>
-<h1>\Bakame\Csv\Reader simple usage</h1>
+<h1>\League\Csv\Reader simple usage</h1>
<table class="table-csv-data">
<caption>Part of the CSV from the 801th row with at most 25 rows</caption>
<thead>
diff --git a/examples/filtering.php b/examples/filtering.php
index 61fcb4d..d4789fb 100644
--- a/examples/filtering.php
+++ b/examples/filtering.php
@@ -1,6 +1,6 @@
<?php
-use Bakame\Csv\Reader;
+use League\Csv\Reader;
require '../vendor/autoload.php';
@@ -36,11 +36,11 @@ $headers = $inputCsv->fetchOne(0);
<html lang="fr">
<head>
<meta charset="<?=$inputCsv->getEncoding()?>">
- <title>\Bakame\Csv\Reader filtering method</title>
+ <title>\League\Csv\Reader filtering method</title>
<link rel="stylesheet" href="example.css">
</head>
<body>
-<h1>Using the Bakame\Csv\Reader class filtering capabilities</h1>
+<h1>Using the League\Csv\Reader class filtering capabilities</h1>
<table class="table-csv-data">
<caption>Statistics for the 20 least used female name in the year 2010</caption>
<thead>
diff --git a/examples/json.php b/examples/json.php
index a679fec..2dcc544 100644
--- a/examples/json.php
+++ b/examples/json.php
@@ -1,6 +1,6 @@
<?php
-use Bakame\Csv\Reader;
+use League\Csv\Reader;
require '../vendor/autoload.php';
diff --git a/examples/merge.php b/examples/merge.php
index cdb9624..848bcc2 100644
--- a/examples/merge.php
+++ b/examples/merge.php
@@ -1,7 +1,7 @@
<?php
-use Bakame\Csv\Writer;
-use Bakame\Csv\Reader;
+use League\Csv\Writer;
+use League\Csv\Reader;
require '../vendor/autoload.php';
@@ -42,7 +42,7 @@ $csv2merge->setDelimiter(',');
/*
When merging multiples CSV documents don't forget to set the main CSV object
- as a `Bakame\Csv\Writer` object with the $open_mode = 'a+' to preserve its content.
+ as a `League\Csv\Writer` object with the $open_mode = 'a+' to preserve its content.
This setting is of course not required when your main CSV object is created from String
*/
@@ -55,7 +55,7 @@ $csv2merge->setDelimiter(',');
<link rel="stylesheet" href="example.css">
</head>
<body>
-<h1>Using the Bakame\Csv\Writer class to merge two CSV documents</h1>
+<h1>Using the League\Csv\Writer class to merge two CSV documents</h1>
<h3>The main Raw CSV</h3>
<p><em>The delimiter is a ";"</em></p>
<pre>
@@ -74,7 +74,7 @@ $csv2merge->setDelimiter(',');
</pre>
<h3>Tips</h3>
<p> When merging multiples CSV documents don't forget to set the main CSV object
- as a <code>Bakame\Csv\Writer</code> object with the <code>$open_mode = 'a+'</code>
+ as a <code>League\Csv\Writer</code> object with the <code>$open_mode = 'a+'</code>
to preserve its content. This setting is of course not required when your main CSV object
is created from String</p>
</body>
diff --git a/examples/switchmode.php b/examples/switchmode.php
index df480eb..97f2391 100644
--- a/examples/switchmode.php
+++ b/examples/switchmode.php
@@ -1,6 +1,6 @@
<?php
-use Bakame\Csv\Writer;
+use League\Csv\Writer;
require '../vendor/autoload.php';
@@ -56,11 +56,11 @@ $names = $reader
<html lang="fr">
<head>
<meta charset="utf-8">
- <title>Bakame\Csv\Writer and Bakame\Csv\Reader switching mode</title>
+ <title>League\Csv\Writer and League\Csv\Reader switching mode</title>
<link rel="stylesheet" href="example.css">
</head>
<body>
-<h1>Using createFromString method and converting the Bakame\Csv\Writer into a Bakame\Csv\Reader</h1>
+<h1>Using createFromString method and converting the League\Csv\Writer into a League\Csv\Reader</h1>
<h3>The table representation of the csv to be save</h3>
<?=$writer->toHTML();?>
<h3>The Raw CSV as it will be saved</h3>
diff --git a/examples/table.php b/examples/table.php
index 5c26ddb..b81633d 100644
--- a/examples/table.php
+++ b/examples/table.php
@@ -1,6 +1,6 @@
<?php
-use Bakame\Csv\Reader;
+use League\Csv\Reader;
require '../vendor/autoload.php';
diff --git a/examples/writing.php b/examples/writing.php
index 948008a..811b8f7 100644
--- a/examples/writing.php
+++ b/examples/writing.php
@@ -1,6 +1,6 @@
<?php
-use Bakame\Csv\Writer;
+use League\Csv\Writer;
require '../vendor/autoload.php';
@@ -27,7 +27,7 @@ $writer->insertAll($teams);
<html lang="fr">
<head>
<meta charset="<?=$writer->getEncoding()?>">
- <title>Using the \Bakame\Writer object</title>
+ <title>Using the \League\Writer object</title>
<link rel="stylesheet" href="example.css">
</head>
<body>
diff --git a/examples/xml.php b/examples/xml.php
index 82052cb..157081e 100644
--- a/examples/xml.php
+++ b/examples/xml.php
@@ -3,7 +3,7 @@
error_reporting(-1);
ini_set('display_errors', 1);
-use Bakame\Csv\Reader;
+use League\Csv\Reader;
require '../vendor/autoload.php';
diff --git a/phpunit.xml b/phpunit.xml
index 55cd758..f610d38 100644
--- a/phpunit.xml
+++ b/phpunit.xml
@@ -12,7 +12,7 @@
stopOnFailure="false">
<testsuites>
- <testsuite name="Bakame CSV Test Suite">
+ <testsuite name="League CSV Test Suite">
<directory>test</directory>
</testsuite>
</testsuites>
diff --git a/test/CsvTest.php b/test/CsvTest.php
index 7a6defa..e10ff76 100644
--- a/test/CsvTest.php
+++ b/test/CsvTest.php
@@ -1,6 +1,6 @@
<?php
-namespace Bakame\Csv;
+namespace League\Csv;
use SplFileInfo;
use SplFileObject;
diff --git a/test/Iterator/IteratorQueryTest.php b/test/Iterator/IteratorQueryTest.php
index 45e7b6f..1f1953e 100644
--- a/test/Iterator/IteratorQueryTest.php
+++ b/test/Iterator/IteratorQueryTest.php
@@ -1,6 +1,6 @@
<?php
-namespace Bakame\Csv\Iterator;
+namespace League\Csv\Iterator;
use ArrayIterator;
use ReflectionClass;
@@ -26,7 +26,7 @@ class IteratorQueryTest extends PHPUnit_Framework_TestCase
private function createTraitObject()
{
- return $this->getObjectForTrait('\Bakame\Csv\Iterator\IteratorQuery');
+ return $this->getObjectForTrait('\League\Csv\Iterator\IteratorQuery');
}
public function setUp()
diff --git a/test/ReaderTest.php b/test/ReaderTest.php
index 8353593..b72ddbd 100644
--- a/test/ReaderTest.php
+++ b/test/ReaderTest.php
@@ -1,6 +1,6 @@
<?php
-namespace Bakame\Csv;
+namespace League\Csv;
use PHPUnit_Framework_TestCase;
use SplTempFileObject;
@@ -165,6 +165,6 @@ EOF;
public function testGetWriter2()
{
$csv = (new Reader(__DIR__.'/foo.csv'))->getWriter('a+');
- $this->assertInstanceOf('\Bakame\Csv\Writer', $csv);
+ $this->assertInstanceOf('\League\Csv\Writer', $csv);
}
}
diff --git a/test/WriterTest.php b/test/WriterTest.php
index 3b4a39d..e886d18 100644
--- a/test/WriterTest.php
+++ b/test/WriterTest.php
@@ -1,6 +1,6 @@
<?php
-namespace Bakame\Csv;
+namespace League\Csv;
use SplTempFileObject;
use ArrayIterator;
diff --git a/src/AbstractCsv.php b/src/AbstractCsv.php
index 4f1582e..4d92418 100644
--- a/src/AbstractCsv.php
+++ b/src/AbstractCsv.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,7 +30,7 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv;
+namespace League\Csv;
use IteratorAggregate;
use JsonSerializable;
@@ -43,7 +43,7 @@ use InvalidArgumentException;
/**
* A abstract class to enable basic CSV manipulation
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.0.0
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/ConverterTrait.php b/src/ConverterTrait.php
index 6748249..d7d34cc 100644
--- a/src/ConverterTrait.php
+++ b/src/ConverterTrait.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,16 +30,16 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv;
+namespace League\Csv;
use DomDocument;
use SplTempFileObject;
-use Bakame\Csv\Iterator\MapIterator;
+use League\Csv\Iterator\MapIterator;
/**
* A abstract class to enable basic CSV manipulation
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.2.0
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/Iterator/IteratorFilter.php b/src/Iterator/IteratorFilter.php
index a7e9662..b313f39 100644
--- a/src/Iterator/IteratorFilter.php
+++ b/src/Iterator/IteratorFilter.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,7 +30,7 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv\Iterator;
+namespace League\Csv\Iterator;
use CallbackFilterIterator;
use Iterator;
@@ -38,7 +38,7 @@ use Iterator;
/**
* A Trait to filter Iterators
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.2.1
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/Iterator/IteratorInterval.php b/src/Iterator/IteratorInterval.php
index 180c4e3..620f7f0 100644
--- a/src/Iterator/IteratorInterval.php
+++ b/src/Iterator/IteratorInterval.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,7 +30,7 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv\Iterator;
+namespace League\Csv\Iterator;
use InvalidArgumentException;
use Iterator;
@@ -39,7 +39,7 @@ use LimitIterator;
/**
* A Trait to Set a LimitIterator object
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.2.1
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/Iterator/IteratorQuery.php b/src/Iterator/IteratorQuery.php
index fbfc9d2..9ea41f4 100644
--- a/src/Iterator/IteratorQuery.php
+++ b/src/Iterator/IteratorQuery.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,14 +30,14 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv\Iterator;
+namespace League\Csv\Iterator;
use Iterator;
/**
* A Trait to Query in a SQL-like manner Iterators
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.0.0
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/Iterator/IteratorSortBy.php b/src/Iterator/IteratorSortBy.php
index c26e85c..0a0a604 100644
--- a/src/Iterator/IteratorSortBy.php
+++ b/src/Iterator/IteratorSortBy.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,7 +30,7 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv\Iterator;
+namespace League\Csv\Iterator;
use Iterator;
use ArrayIterator;
@@ -38,7 +38,7 @@ use ArrayIterator;
/**
* A Trait to sort an Iterator
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.2.1
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/Iterator/MapIterator.php b/src/Iterator/MapIterator.php
index 3b3c9a7..d3a3467 100644
--- a/src/Iterator/MapIterator.php
+++ b/src/Iterator/MapIterator.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,7 +30,7 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv\Iterator;
+namespace League\Csv\Iterator;
use IteratorIterator;
use Traversable;
@@ -38,7 +38,7 @@ use Traversable;
/**
* A simple MapIterator
*
- * @package Bakame.csv
+ * @package League.csv
* @since 3.3.0
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/Reader.php b/src/Reader.php
index a8d6432..3b21e34 100644
--- a/src/Reader.php
+++ b/src/Reader.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,19 +30,19 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv;
+namespace League\Csv;
use SplFileObject;
use SplTempFileObject;
use InvalidArgumentException;
use CallbackFilterIterator;
-use Bakame\Csv\Iterator\MapIterator;
-use Bakame\Csv\Iterator\IteratorQuery;
+use League\Csv\Iterator\MapIterator;
+use League\Csv\Iterator\IteratorQuery;
/**
* A class to manage extracting and filtering a CSV
*
- * @package Bakame.csv
+ * @package League.csv
* @since 3.0.0
*
*/
@@ -192,7 +192,7 @@ class Reader extends AbstractCsv
*
* @param string $open_mode the file open mode flag
*
- * @return \Bakame\Csv\Writer
+ * @return \League\Csv\Writer
*/
public function getWriter($open_mode = 'w')
{
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
diff --git a/src/Writer.php b/src/Writer.php
index c047953..50784fc 100644
--- a/src/Writer.php
+++ b/src/Writer.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,7 +30,7 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv;
+namespace League\Csv;
use InvalidArgumentException;
use Traversable;
@@ -38,7 +38,7 @@ use Traversable;
/**
* A class to manage data insertion into a CSV
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.0.0
*
*/
@@ -111,7 +111,7 @@ class Writer extends AbstractCsv
/**
* Instantiate a {@link Reader} class from the current {@link Writer}
*
- * @return \Bakame\Csv\Reader
+ * @return \League\Csv\Reader
*/
public function getReader()
{
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>